#ifndef _FRAME_H
#define _FRAME_H

#include "wx.h"
#include "BscFrame.h"

/* 
CLASS
   Frame

 This class represents the abstraction of a graphical user interface
 window. The methods of this class allow for simple text and graphics
 to be displayed in the window. Under program control, the window
 may be moved on the user's display and its shape may be changed.
 Each Frame is given a name that is appears on the title bar of the
 visible window and is used to identify the Frame when mouse events
 occur in that window.
 The location of a Frame on the user's display is measured in a
  coordinate system where the upper left-hand corner of the display is
  the coordinates (0,0), the x-axis is the top of the display with higher
  x values to the right, and the y-axis is the left edge of the display
  with higher values nearer the bottom of the display.
  The shape of a Frame is given by it width and height, both measures
  in pixels. 
  The Frame class declares several named constants that are used to
  identify the nature of mouse events that occur in a window.


*/



class Frame    { // version 2
public:
  //////////
  //Construct a Frame object specifying the Frame's name, its location -
  //the x and y coordinates, and its shape - its width and height.
  //
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //            will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //
  //<LI><B>x</B> the x coordinate of where the Frame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           left-hand edge of the display.</LI>
  //
  //<LI><B>y</B> the y coordinate of where the Frame's upper left-hand
  //           corner  is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           top edge of the display.</LI>
  //
  //<LI><B>width</B> the width of the Frame's window measured in pixels.</LI>
  //
  //<LI><B>height</B> the height of the Frame's window measured in pixels.</LI>
  //</UL>
    Frame(char* name, int x, int y, int width, int height);

  //////////
  // Construct a Frame object specifying the Frame's name, and its location -
  // the x and y coordinates. Default values are used for the Frame's
  // height and width.
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //            will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //
  //<LI><B>x</B> the x coordinate of where the Frame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           left-hand edge of the display.</LI>
  //
  //<LI><B>y</B> the y coordinate of where the Frame's upper left-hand
  //           corner  is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           top edge of the display.</LI>
  //</UL>
  Frame(char* name, int x, int y);

  //////////
  //Construct a Frame object specifying the Frame's name. The Frames
  //location (x and y coordinates) and its shape (width and height) are
  //given default values. 
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //            will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //
  //</UL>
  Frame(char* name);

  //////////
  // Construct a Frame object with default values used for its name, location,
  // and shape. 
  Frame();

  //////////
  // Change the location of a window on the user's display. The (x,y)
  // coordinates of the upper left-hand corner of the Frame's new position
  // relative to the upper left-hand corner of the user's display are given.
  //
  //<UL>
  //<LI><B>newX</B> the new x coordinate </LI>
  //<LI><B>newy</B> the new y coordinate </LI>>
  //</UL>
  void  MoveTo(int newX, int newY);           

  //////////
  // Change the shape of a window. Both the new width and the new height
  // of the window must be given.
  //
  //<UL>
  //<LI><B>newWidth</B> the width of the window after the method is complete
  //       </LI>>
  //<LI><B>newHeight</B> the height of the window after the method is complete   //</LI>
  //</UL>
  void  Resize(int newWidth, int newHeight);        

   //////////
   // Change the dimensions of the Frame's visible window by multiplying
   // each dimension by a given amount.
   //<UL>
   // <LI><B>factor</B>: the amount by which the window's height and
   //width are multiplied. If factor &gt; 1, the window will increase in
   //size. If factor &lt; 1, the window will decrease in size.
   //</UL>
   void     Resize( float factor);              


  //////////
  // Draw a text string at a given location in a window. The displayed 
  // text is drawn in a rectangular area whose upper left-hand corner is
  // given by the x and y parameters.
  //<UL>
  // <LI><B> msg </B> the characters to appear in the window</LI>
  // <LI><B> x </B> the x coordinate of where the text will begin</LI>
  // <LI><B> y </B> the y coordinate of where the text will begin</LI>
  //</UL>
   void  DrawText(char* msg, int x,  int  y);

   //////////
   // Return the width and height of the rectangular area occupied in 
   // the window by the given text string. This method is useful in 
   // erasing a given text string (see the Clear method). The <I>width</I>
   // and <I>height</I> arguments are passed by reference so that the
   // two integer values can be returned to the caller.
   //<UL>
   // <LI><B>msg</B>: the text string whose shape is determined. </LI>
   // <LI><B>width</B>: the width of the given text string. </LI>
   // <LI><B>height</B>: the height of the given text  string. </LI>
   //</UL>
   void TextSize (char* msg, int& width, int& height);               


  //////////
  // Draw a line between two points. Each point is denoted by an (x,y)
  // coordinate pair.
  //<UL>
  //<LI><B> x1 </B> x coordinate of one end</LI>
  //<LI><B> y1 </B> y coordinate of one end</LI>
  //<LI><B> x2 </B> x coordinate of the other end</LI>
  //<LI><B> y2 </B> y coordinate of the other end</LI>
  //</UL>
  void  DrawLine(int x1, int y1, int x2, int y2);          

  //////////
  //Draw a circle at a given location with a given radius.
  //<UL>
  //<LI><B>x </B> the x coordinate of the center of the circle</LI>
  //<LI><B>y </B> the y coordinate of the center of the circle</LI>
  //<LI><B>radius </B> the radius of the circle in pixels</LI>
  //</UL>
    void  DrawCircle(int x, int y, int radius);
                                               
  //////////
  // Erase the contents of the window. All text and graphics displayed 
  // in the window will be  erased. Typically, this method is used before
  // refreshing/redrawing the contents of the window to insure that all
  // text/graphics previously drawn are erased.
    void  Clear();
 
  //////////
  // Indicate if the Frame has a name equal to that of the string given as 
  // the parameter. This method is typically used in the onMouseEvent
  // method to determine in which Frame a given mouse event occurred.
  //<UL>
  //<LI> <B>name</B>  the string whose value is tested against the 
  //                    name of the Frame.</LI>
   //</UL>
   int   IsNamed(char* name);      
 
  //////////
  //Dispose of all resource associated with this object and its window.
  //
  void ~Frame();
};









