#ifndef _TEXTFRAME_H_
#define _TEXTFRAME_H_

#include "BasicFrame.h"
#include "wx.h"


#define endl '\n'


/*
CLASS
  TextFrame

  This class captures the abstraction of a window which displays
  a text stream. The class provides a stream output operator
  ("&lt;&lt;") for each of the C++ built-in types. The methods for
   placing and sizing of a TextFrame object are the same as for a Frame
  object.The constant "endl" is defined for a TextFrame so that it has the
  same meaning as for standard streams such as cout, namely, that it
  terminates the end of the current line of output.
  
*/



class TextFrame {
 private:
   int               xCoord, yCoord, height, width;
   char             *name;
   BasicTextFrame   *frame;

   void CreateIfNeeded();

public:

   //////////
   //Construct a TextFrame object specifying the TextFrame's name, 
   // its location - the x and y coordinates, and its shape - 
   // its width and height.
   //<UL>
   //<LI><B>name</B>: this string defines the name of the TextFrame. 
   //           This string will
  //            appear on the top border of the window on the user's
  //            display.
  //
  //<LI><B>x</B> the x coordinate of where the TextFrame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           left-hand edge of the display.</LI>
  //
  //<LI><B>y</B> the y coordinate of where the TextFrame's upper left-hand
  //           corner  is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           top edge of the display.</LI>
  //
  //<LI><B>width</B> the width of the TextFrame's window measured in pixels.
  //</LI>
  //
  //<LI><B>height</B> the height of the TextFrame's window measured in pixels.
  //</LI>
  //</UL>
   TextFrame(char *name, int x, int y, int w, int h);


  //////////
  // Construct a TextFrame object specifying the TextFrame's name, and its 
  // location - the x and y coordinates. Default values are used for the
  //  Frame's height and width.
   //<UL>
   //<LI><B>name</B>: this string defines the name of the TextFrame. 
   //           This string will
  //            appear on the top border of the window on the user's
  //            display.
  //
  //<LI><B>x</B> the x coordinate of where the TextFrame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           left-hand edge of the display.</LI>
  //
  //<LI><B>y</B> the y coordinate of where the TextFrame's upper left-hand
  //           corner  is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //           It is measured in pixels of how far the point is from the 
  //           top edge of the display.</LI>
  //
  //</UL>
   TextFrame(char* name, int x, int y);


  //////////
  //Construct a TextFrame object specifying the TextFrame's name. The 
  //TextFrame's
  //location (x and y coordinates) and its shape (width and height) are
  //given default values. 
   //<UL>
   //<LI><B>name</B>: this string defines the name of the TextFrame. 
   //           This string will
  //            appear on the top border of the window on the user's
  //            display.
  //</UL>
   TextFrame(char* name);


  //////////
  // Construct a TextFrame object with default values used for its 
  // name, location, and shape. 
   TextFrame();


  //////////
  //Dispose of all resource associated with this object and its window.
  //
  ~TextFrame();
            

  //////////
  // Change the location of a window on the user's display. The (x,y)
  // coordinates of the upper left-hand corner of the TextFrame's new position
  // relative to the upper left-hand corner of the user's display are given.
  //
  //<UL>
  //<LI><B>newX</B> the new x coordinate </LI>
  //<LI><B>newy</B> the new y coordinate </LI>>
  //</UL>
   void     MoveTo( int newx, int newy);        // change position

   //////////
   //
  //////////
  // Change the shape of a window. Both the new width and the new height
  // of the window must be given.
  //
  //<UL>
  //<LI><B>newWidth</B> the width of the window after the method is complete
  //       </LI>>
  //<LI><B>newHeight</B> the height of the window after the method is complete   //</LI>
  //</UL>
   void     Resize( int newWidth, int newHeight);              // change shape


   //////////
   // Change the dimensions of the TextFrame's visible window by multiplying
   // each dimension by a given amount.
   //<UL>
   // <LI><B>factor</B>: the amount by which the window's height and
   //width are multiplied. If factor &gt; 1, the window will increase in
   //size. If factor &lt; 1, the window will decrease in size.
   //</UL>
   void     Resize( float factor);              //

  //////////
  // Indicate if the Frame has a name equal to that of the string given as 
  // the parameter. 
  //<UL>
  //<LI> <B>name</B>  the string whose value is tested against the 
  //                    name of the TextFrame.</LI>
   //</UL>
   int      IsNamed(char* name);                   // is this your name?

   //////////
   // Add to the output stream a string of characters. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>s </B>: a pointer to the null-terminated string of characters
   // to be added to the TextFrame's output stream.</LI>
   //</UL>
   TextFrame& operator<<(char  *s);

   //////////
   // Add to the output stream a string of characters that represents
   // the value of an integer. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>i </B>: the integer whose text string representation
   // is to be added to the TextFrame's output stream.</LI>
   //</UL>
   TextFrame& operator<<(int    i);

   //////////
   // Add to the output stream a string of characters that represents
   // the value of a long integer. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>l </B>: the long integer whose text string representation
   // is to be added to the TextFrame's output stream.</LI>
   //</UL>
   TextFrame& operator<<(long   l);

   //////////
   // Add to the output stream a string of characters that represents
   // the value of a floating point number. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>f </B>: the floating point number whose text string
   // representation is to be added to the TextFrame's output stream.</LI>
   //</UL>
   TextFrame& operator<<(float  f);

   //////////
   // Add to the output stream a string of characters that represents
   // the value of a double precision floating point number. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>d </B>: the double precision floating point number whose
   // text string representation is 
   // to be added to the TextFrame's output stream.</LI>
   //</UL>
   TextFrame& operator<<(double d);

   //////////
   // Add to the output stream a singe character. The operation 
   // returns a reference to the modified TextFrame so that 
   // stream output operations can be performed in sequence.
   //<UL>
   //<LI><B>c </B>: the character to be added to the TextFrame's 
   //output stream.</LI>
   //</UL>
   TextFrame& operator<<(char   c);

};


#endif


