#ifndef _FILE_H
#define _FILE_H

#include "Query.h"

/*
CLASS
    File

    This class captures the abstraction of a disk-based file. A File
    object can be directly constructed with the name of a file in the
    file system or it may be returned by a file dialogue such as
    FileQuery, FileChooser, or FileNavigator. The File class provides
    methods to query the name of the file, determine if the file
    actually exists, to search the file for a given text string, to
    view/edit the file in a window, to copy one file to another, and
    to delete the file from the file system.
*/

class File {
private:
   char* name;

public:

       //////////
       // Construct a File object with a given name. No check is made
       // that the file so named actually exists in the file system
       // (see the <I>Exists</I> method). 
       //<UL>
       //<LI><B></B>: </LI>
       //</UL>
       File(char* fileName);               

       //////////
       // Construct a  File object that denotes an unnamed file.
       File();                             

       //////////
       // Return the name of the file.
 char* Name();                             

       //////////
       // Determine if a file with the name corresponding to the File
       // object's name actually exists in the file system. Returns a
       // 1 if the file exists and a 0 otherwise.
 int   Exists();                           

       //////////
       // Search the file using a supplied Query. The Query is passed by
       // reference so that it can be changed as a result of the searching.
       //<UL>
       //<LI><B>query</B>: the query that supplies the text string to
       // be searched for and contain the result of the search.</LI>
       //</UL>
 void  SearchFor(Query& query);                

       //////////
       // View the contents of the file in a window. The view 
       // is read-only, the window does not allow editing. This method
       // assumes that the file is a text file or can otherwise be
       // presented meaningfully in a window.
 void  View();                             

       //////////
       // Launch a given text editor to edit the contents of the file.
       // The editor is identified by a pathname in the local file system
       // of an executable file. This method assumes that the file is a
       // text file or can otherwise be meaningfully handled by the
       // given editing program.
       //<UL>
       //<LI><B>editor</B>: the pathname of an editing program on the
       // local machine.</LI>
       //</UL>
 void  Edit(char* editor);                 

       //////////
       // Remove the file from the local file system. This method is
       // irreversible. The method deletes the file, but not the File
       // object.
 void  Delete();                           

       //////////
       // Copy the contents of this file to the file specified by the
       // argument. The current file is unaffected by the operation.
       //<UL>
       //<LI><B>other</B>: the file to which the copying will be done.</LI>
       //</UL>
 void  CopyTo(File& other);                

       //////////
       // Overwrite the contents of this file with the contents of the file
       // denoted by the argument. The argument's file is unaffected by the
       // operation.
       //<UL>
       //<LI><B>other</B>: the file that is the source of the copying to
       // be done.</LI>
       //</UL>
 void  CopyFrom(File& other);              

       //////////
       // Reclaim the resources associated with the File object. This does
       // NOT delete the corresponding disk file (see Delete).
      ~File();                             
};

#endif
