#ifndef _CANVAS_H
#define _CANVAS_H

#include "wx.h"
#include "Location.h"
#include "Shape.h"
#include "Frame.h"


class Canvas;
class BasicFrame;

void OnPaint();

class DrawingCanvas: public wxCanvas
{
    Canvas *canvas;

  public:
    DrawingCanvas(BasicFrame *frame, Canvas* cvs, int x, int y, int w, int h, 
                              long style = wxRETAINED);
    ~DrawingCanvas(void) ;
    void OnPaint();
    void OnEvent(wxMouseEvent& event);
};

/*
CLASS 
   Canvas

  The Canvas class captures the abstraction of a named, interactive surface 
  on which text and graphics can be drawn. Methods are provided for 
  drawing lines, circles, and text strings. Mouse events that happen
  within the boundaries of the displayed Canvas are reported by
  calling the OnMouseEvent function passing the name of the  Canvas
  as an argument. Erasure of the entire canvas
  or of a selected rectangular region is provided. 
*/

class Canvas {
 private:
   DrawingCanvas *dc;          // hidden drawing area
   char          *name;        
   Location       location;
   Shape          shape;
   Frame         *frame;       // Frame to which this is attached
   void CreateIfNeeded();
   friend class Message;
   friend class BlinkingMessage;
 public:

   //////////
   // Construct a Canvas as a region within an existing Frame. In 
   // addition to the Canvas's name (used for reporting the occurrence
   // of mouse events within the Canvas's area), the Location within
   // the Frame and the Shape of the Canvas are specified. It is
   // important that the Frame be of sufficient size so that the 
   // Canvas' position  and dimensions allow the Canvas to be  
   // entirely contained within the Frame.
   //<UL>
   //<LI><B>frame </B>: the Frame object in which the Canvas will appear.</LI>
   //<LI><B>name </B>: the name of the Canvas (used for reporting mouse
   // events that occur within the Canvas's area. </LI>
   //<LI><B>location </B>: the position in the Frame of the upper left-hand 
   // corner of the Canvas's rectangular region. </LI>
   //<LI><B>shape </B>: the dimensions of the Canvas.</LI>
   //</UL>
   Canvas(Frame& frame, char *name, Location location, Shape shape);

   //////////
   // Set the Color to be used when drawing text or graphics. This color
   // remains in effect for all subsequent drawing operations until the  
   // drawing color is changed. Different Canvases may, of course, have
   // different drawing colors.
   //<UL>
   //<LI><B>color </B>: the color to be used in subsequent drawing
   // operations </LI>
   void SetDrawColor(Color color);

   //////////
   // Set the Color to be used when filling closed graphics shapes. This color
   // remains in effect for all subsequent filling operations until the  
   // filling color is changed. Different Canvases may, of course, have
   // different filling colors.
   //<UL>
   //<LI><B>color </B>: the color to be used in subsequent filling
   // operations </LI>
   void SetFillColor(Color color);

   //////////
   // Draw a text string in the Frames' visible window starting at the
   // specified location.
   //<UL>
   // <LI><B>msg</B>: the text string to be drawn. </LI>
   // <LI><B>location</B>: the upper left-hand corner of where within
   //the window the first character of the string will be drawn. The
   //coordinates of the Location are interpreted with respect to the
   // upper left-hand corner of the window.</LI>
   //</UL>
   void     DrawText(char* msg, Location loc);  
   
   //////////
   // Return the Shape of the rectangular area occupied by the given
   // text string when the string is displayed in the Canvas. This 
   // method is typically used in conjunction with the <I>Clear</I> method
   // that requires a Shape as one of its argument.
   //<UL>
   //<LI><B> msg </B>: the text string whose displayed Shape is to be found. 
   //  </LI>
   //</UL>
   Shape    TextSize (char* msg);               

   //////////
   // Draw a line segment between two points whose Locations are specified.
   //<UL>
   // <LI><B>p1</B>: one end of the line segment. </LI>
   // <LI><B>p2</B>: the other end of the line segment.</LI>
   //</UL>
   void     DrawLine(Location p1, Location p2);

   //////////
   // Draw a circle of the specified radius about a specified centerpoint.
   //<UL>
   // <LI><B>center</B>: the center point of the circle. </LI>
   // <LI><B>radius</B>: the radius of the circle.</LI>
   //</UL>
   void     DrawCircle(Location center, int r); 
                                                
   //////////
   // Erase the contents of the Frame's visible window.
   void     Clear();   
                         
   //////////
   // Erase a specified rectangular region of the Frame's visible window.
   //Only the specified rectangular region is affected.
   //<UL>
   // <LI><B>location</B>: the coordinates of the upper left-hand
   // corner of the rectangular area to be erased.</LI>
   // <LI><B>shape</B>: the height and width of the rectangular
   // area to be erased.</LI>
   //</UL>
   void     Clear(Location loc, Shape sh);      

   //////////
   // Return the name of the Canvas. The name of the Canvas is
   // defined by the Canvas's constructor. The name is useful in
   // determining in which Canvas a given mouse event occured.
   char*    getName();                      
    
   //////////
   // Destructor: deallocate resources held by the Canvas object.
  ~Canvas();
 };





#endif






