#ifndef _RECTANGLE2_H
#define _RECTANGLE2_H

#include "Location.h"
#include "Shape.h"
#include "Canvas.h"

/*
CLASS
  Rectangle3

  This class represents a rectangular shape that is constructed only
  the the RectangleFactory that guarantees that all objects it produces
  have the same Shape. To insure the uniformity of their Shapes, the
  Rectangle3 constructor is private and the RectangleFactory is
  declared as a <I>friend</I> class so that it alone has access to
  the Rectangle3 constructor. The dimensions and initial
  position of the Rectangle3 within a Canvas are specified when the   
  Rectangle3 is constructed by the RectangleFactory. 
  The Rectangle3 may be moved relative to its
  current positions, drawn, and erased, but not resized.

  This class uses a static (class) variable defined as:
  <PRE>  
        static Color rectangleColor; 
 
  </PRE>
  which is the color used to draw all rectangles. The <I>SetColor</I>
  method changes this static (class) variable and, thereby, affects
  the drawing color of <B>all</B> rectangles. 

  

*/

class Rectangle3
{
  private:
	  Location upperLeft;
	  Location upperRight;
	  Location lowerLeft;
	  Location lowerRight;
	  Shape    area;

          static Color rectangleColor;
          void AdjustCorners();

          //////////
          // Construct a Rectangle3 object that represents a rectangular
          // shape at a given position.
          //<UL>
	  //<LI><B>corner </B>: the Location of the upper left-hand
          // corner of the rectangle</LI>
	  //<LI><B>shape </B>: the dimesions (width and height) of the
          // rectangle.</LI>
          //</UL>
	  Rectangle3 (Location corner, Shape shape);

  public:
     
          //////////
          // Move the Location of the rectangle a given amount toward
          // the top edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaY </B>: the amount to move the rectangle toward
          // the top edge from its current position.</LI>
          //</UL>
	  void MoveUp    (int deltaY);

          //////////
          // Move the Location of the rectangle a given amount toward
          // the bottom edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaY </B>: the amount to move the rectangle toward
          // the bottom edge from its current position.</LI>
          //</UL>
	  void MoveDown  (int deltaY);

          //////////
          // Move the Location of the rectangle a given amount toward
          // the left edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaX </B>: the amount to move the rectangle toward
          // the left edge from its current position.</LI>
          //</UL>
	  void MoveLeft  (int deltaX);

          //////////
          // Move the Location of the rectangle a given amount toward
          // the right edge of the Canvas relative to its current
          // position.
          //<UL>
	  //<LI><B>deltaX </B>: the amount to move the rectangle toward
          // the right edge from its current position.</LI>
          //</UL>
	  void MoveRight (int deltaX);


          //////////
          // Draw the rectangle at its current position in a given
          // Canvas.
          //<UL>
	  //<LI><B>canvas </B>: the Canvas in which the rectangle
          //is drawn.</LI>
          //</UL>
	  void Draw(Canvas& canvas);

          //////////
          //  Erase the rectangle from the given Canvas in which it
	  // is drawn. Note: no check is made that the rectangle
          // is actually drawn in this Canvas; it is the programmer's
          // responsibility to insure this condition.
          //<UL>
	  //<LI><B>canvas</B>: the Canvas from which the rectangle
          // is to be erased.</LI>
          //</UL>
	  void Clear(Canvas& canvas);

          //////////
          // Change the color of all rectangles. This is accomplished
          // by setting the static (class) variable that records the
          // color used in drawing the rectangle. A rectangles will
          // be affected by this change the next time that it is
          // redrawn.
          //<UL>
          //<LI><B>color </B>: the new Color for all rectangles </LI>
          //</UL>
	  void SetColor(Color color);


          //////////
          // Release the resources held by the Rectangle3 object.
	  ~Rectangle3();
};

#endif
